==> vala-0.1.1.tar.gz: vala-0.1.1/vala/valadestructor.c <==
/* valadestructor.vala
 *
 * Copyright (C) 2006-2007  Jürg Billeter
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.

 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.

 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA
 *
 * Author:
 * 	Jürg Billeter <j@bitron.ch>
 */
#define VALA_FREE_CHECKED(o,f) ((o) == NULL ? NULL : ((o) = (f (o), NULL)))
#define VALA_FREE_UNCHECKED(o,f) ((o) = (f (o), NULL))

#include "valadestructor.h"
#include <vala/valastatement.h>
#include <vala/valasourcereference.h>
#include <vala/valacodevisitor.h>
#include <vala/valadestructor.h>

struct _ValaDestructorPrivate {
	ValaStatement* _body;
	gboolean _instance;
};
#define VALA_DESTRUCTOR_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_DESTRUCTOR, ValaDestructorPrivate))
enum  {
	VALA_DESTRUCTOR_DUMMY_PROPERTY,
	VALA_DESTRUCTOR_BODY,
	VALA_DESTRUCTOR_INSTANCE
};
static void vala_destructor_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor);
static void vala_destructor_real_accept_children (ValaCodeNode* base, ValaCodeVisitor* visitor);
static gpointer vala_destructor_parent_class = NULL;
static void vala_destructor_dispose (GObject * obj);


/**
 * Creates a new destructor.
 *
 * @param source reference to source code
 * @return       newly created destructor
 */
ValaDestructor* vala_destructor_new (ValaSourceReference* source)
{
	GParameter * __params;
	GParameter * __params_it;
	ValaDestructor * self;
	g_return_val_if_fail (source == NULL || VALA_IS_SOURCE_REFERENCE (source), NULL);
	__params = g_new0 (GParameter, 1);
	__params_it = __params;
	(__params_it->name = "source-reference", g_value_init (&__params_it->value, VALA_TYPE_SOURCE_REFERENCE), g_value_set_object (&__params_it->value, source), __params_it++);
	self = g_object_newv (VALA_TYPE_DESTRUCTOR, __params_it - __params, __params);
	return self;
}


static void vala_destructor_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor)
{
	ValaDestructor * self;
	self = VALA_DESTRUCTOR (base);
	g_return_if_fail (VALA_IS_CODE_VISITOR (visitor));
	vala_code_visitor_visit_destructor (visitor, self);
}


static void vala_destructor_real_accept_children (ValaCodeNode* base, ValaCodeVisitor* visitor)
{
	ValaDestructor * self;
	self = VALA_DESTRUCTOR (base);
	g_return_if_fail (VALA_IS_CODE_VISITOR (visitor));
	if (vala_destructor_get_body (self) != NULL) {
		vala_code_node_accept (VALA_CODE_NODE (vala_destructor_get_body (self)), visitor);
	}
}


ValaStatement* vala_destructor_get_body (ValaDestructor* self)
{
	g_return_val_if_fail (VALA_IS_DESTRUCTOR (self), NULL);
	return self->priv->_body;
}


void vala_destructor_set_body (ValaDestructor* self, ValaStatement* value)
{
	ValaStatement* __temp2;
	ValaStatement* __temp1;
	g_return_if_fail (VALA_IS_DESTRUCTOR (self));
	__temp2 = NULL;
	__temp1 = NULL;
	self->priv->_body = (__temp2 = (__temp1 = value, (__temp1 == NULL ? NULL : g_object_ref (__temp1))), (self->priv->_body == NULL ? NULL : (self->priv->_body = (g_object_unref (self->priv->_body), NULL))), __temp2);
}


gboolean vala_destructor_get_instance (ValaDestructor* self)
{
	g_return_val_if_fail (VALA_IS_DESTRUCTOR (self), FALSE);
	return self->priv->_instance;
}


void vala_destructor_set_instance (ValaDestructor* self, gboolean value)
{
	g_return_if_fail (VALA_IS_DESTRUCTOR (self));
	self->priv->_instance = value;
}


static void vala_destructor_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec)
{
	ValaDestructor * self;
	self = VALA_DESTRUCTOR (object);
	switch (property_id) {
		case VALA_DESTRUCTOR_BODY:
		g_value_set_object (value, vala_destructor_get_body (self));
		break;
		case VALA_DESTRUCTOR_INSTANCE:
		g_value_set_boolean (value, vala_destructor_get_instance (self));
		break;
	}
}


static void vala_destructor_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec)
{
	ValaDestructor * self;
	self = VALA_DESTRUCTOR (object);
	switch (property_id) {
		case VALA_DESTRUCTOR_BODY:
		vala_destructor_set_body (self, g_value_get_object (value));
		break;
		case VALA_DESTRUCTOR_INSTANCE:
		vala_destructor_set_instance (self, g_value_get_boolean (value));
		break;
	}
}


static void vala_destructor_class_init (ValaDestructorClass * klass)
{
	vala_destructor_parent_class = g_type_class_peek_parent (klass);
	g_type_class_add_private (klass, sizeof (ValaDestructorPrivate));
	G_OBJECT_CLASS (klass)->get_property = vala_destructor_get_property;
	G_OBJECT_CLASS (klass)->set_property = vala_destructor_set_property;
	G_OBJECT_CLASS (klass)->dispose = vala_destructor_dispose;
	VALA_CODE_NODE_CLASS (klass)->accept = vala_destructor_real_accept;
	VALA_CODE_NODE_CLASS (klass)->accept_children = vala_destructor_real_accept_children;
	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_DESTRUCTOR_BODY, g_param_spec_object ("body", "foo", "bar", VALA_TYPE_STATEMENT, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_DESTRUCTOR_INSTANCE, g_param_spec_boolean ("instance", "foo", "bar", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
}


static void vala_destructor_init (ValaDestructor * self)
{
	self->priv = VALA_DESTRUCTOR_GET_PRIVATE (self);
	self->priv->_instance = TRUE;
}


static void vala_destructor_dispose (GObject * obj)
{
	ValaDestructor * self;
	ValaDestructorClass * klass;
	GObjectClass * parent_class;
	self = VALA_DESTRUCTOR (obj);
	(self->priv->_body == NULL ? NULL : (self->priv->_body = (g_object_unref (self->priv->_body), NULL)));
	klass = VALA_DESTRUCTOR_CLASS (g_type_class_peek (VALA_TYPE_DESTRUCTOR));
	parent_class = G_OBJECT_CLASS (g_type_class_peek_parent (klass));
	parent_class->dispose (obj);
}


GType vala_destructor_get_type ()
{
	static GType vala_destructor_type_id = 0;
	if (G_UNLIKELY (vala_destructor_type_id == 0)) {
		static const GTypeInfo g_define_type_info = { sizeof (ValaDestructorClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_destructor_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaDestructor), 0, (GInstanceInitFunc) vala_destructor_init };
		vala_destructor_type_id = g_type_register_static (VALA_TYPE_CODE_NODE, "ValaDestructor", &g_define_type_info, 0);
	}
	return vala_destructor_type_id;
}

==> vala_0.1.2.orig.tar.gz: vala-0.1.2/vala/valadestructor.c <==
/* valadestructor.vala
 *
 * Copyright (C) 2006-2007  Jürg Billeter
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.

 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.

 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA
 *
 * Author:
 * 	Jürg Billeter <j@bitron.ch>
 */

#include "valadestructor.h"
#include <vala/valablock.h>
#include <vala/valasourcereference.h>
#include <vala/valacodevisitor.h>
#include <vala/valadestructor.h>

struct _ValaDestructorPrivate {
	ValaBlock* _body;
	gboolean _instance;
};
#define VALA_DESTRUCTOR_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_DESTRUCTOR, ValaDestructorPrivate))
enum  {
	VALA_DESTRUCTOR_DUMMY_PROPERTY,
	VALA_DESTRUCTOR_BODY,
	VALA_DESTRUCTOR_INSTANCE
};
static void vala_destructor_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor);
static void vala_destructor_real_accept_children (ValaCodeNode* base, ValaCodeVisitor* visitor);
static gpointer vala_destructor_parent_class = NULL;
static void vala_destructor_dispose (GObject * obj);


/**
 * Creates a new destructor.
 *
 * @param source_reference reference to source code
 * @return                 newly created destructor
 */
ValaDestructor* vala_destructor_new (ValaSourceReference* source_reference)
{
	ValaDestructor * self;
	g_return_val_if_fail (source_reference == NULL || VALA_IS_SOURCE_REFERENCE (source_reference), NULL);
	self = g_object_newv (VALA_TYPE_DESTRUCTOR, 0, NULL);
	vala_code_node_set_source_reference (VALA_CODE_NODE (self), source_reference);
	return self;
}


static void vala_destructor_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor)
{
	ValaDestructor * self;
	self = ((ValaDestructor*) base);
	g_return_if_fail (VALA_IS_CODE_VISITOR (visitor));
	vala_code_visitor_visit_destructor (visitor, self);
}


static void vala_destructor_real_accept_children (ValaCodeNode* base, ValaCodeVisitor* visitor)
{
	ValaDestructor * self;
	self = ((ValaDestructor*) base);
	g_return_if_fail (VALA_IS_CODE_VISITOR (visitor));
	if (vala_destructor_get_body (self) != NULL) {
		vala_code_node_accept (VALA_CODE_NODE (vala_destructor_get_body (self)), visitor);
	}
}


ValaBlock* vala_destructor_get_body (ValaDestructor* self)
{
	g_return_val_if_fail (VALA_IS_DESTRUCTOR (self), NULL);
	return self->priv->_body;
}


void vala_destructor_set_body (ValaDestructor* self, ValaBlock* value)
{
	ValaBlock* __temp2;
	ValaBlock* __temp1;
	g_return_if_fail (VALA_IS_DESTRUCTOR (self));
	__temp2 = NULL;
	__temp1 = NULL;
	self->priv->_body = (__temp2 = (__temp1 = value, (__temp1 == NULL ? NULL : g_object_ref (__temp1))), (self->priv->_body == NULL ? NULL : (self->priv->_body = (g_object_unref (self->priv->_body), NULL))), __temp2);
}


gboolean vala_destructor_get_instance (ValaDestructor* self)
{
	g_return_val_if_fail (VALA_IS_DESTRUCTOR (self), FALSE);
	return self->priv->_instance;
}


void vala_destructor_set_instance (ValaDestructor* self, gboolean value)
{
	g_return_if_fail (VALA_IS_DESTRUCTOR (self));
	self->priv->_instance = value;
}


static void vala_destructor_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec)
{
	ValaDestructor * self;
	self = VALA_DESTRUCTOR (object);
	switch (property_id) {
		case VALA_DESTRUCTOR_BODY:
		g_value_set_object (value, vala_destructor_get_body (self));
		break;
		case VALA_DESTRUCTOR_INSTANCE:
		g_value_set_boolean (value, vala_destructor_get_instance (self));
		break;
	}
}


static void vala_destructor_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec)
{
	ValaDestructor * self;
	self = VALA_DESTRUCTOR (object);
	switch (property_id) {
		case VALA_DESTRUCTOR_BODY:
		vala_destructor_set_body (self, g_value_get_object (value));
		break;
		case VALA_DESTRUCTOR_INSTANCE:
		vala_destructor_set_instance (self, g_value_get_boolean (value));
		break;
	}
}


static void vala_destructor_class_init (ValaDestructorClass * klass)
{
	vala_destructor_parent_class = g_type_class_peek_parent (klass);
	g_type_class_add_private (klass, sizeof (ValaDestructorPrivate));
	G_OBJECT_CLASS (klass)->get_property = vala_destructor_get_property;
	G_OBJECT_CLASS (klass)->set_property = vala_destructor_set_property;
	G_OBJECT_CLASS (klass)->dispose = vala_destructor_dispose;
	VALA_CODE_NODE_CLASS (klass)->accept = vala_destructor_real_accept;
	VALA_CODE_NODE_CLASS (klass)->accept_children = vala_destructor_real_accept_children;
	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_DESTRUCTOR_BODY, g_param_spec_object ("body", "foo", "bar", VALA_TYPE_BLOCK, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_DESTRUCTOR_INSTANCE, g_param_spec_boolean ("instance", "foo", "bar", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
}


static void vala_destructor_init (ValaDestructor * self)
{
	self->priv = VALA_DESTRUCTOR_GET_PRIVATE (self);
	self->priv->_instance = TRUE;
}


static void vala_destructor_dispose (GObject * obj)
{
	ValaDestructor * self;
	ValaDestructorClass * klass;
	GObjectClass * parent_class;
	self = VALA_DESTRUCTOR (obj);
	(self->priv->_body == NULL ? NULL : (self->priv->_body = (g_object_unref (self->priv->_body), NULL)));
	klass = VALA_DESTRUCTOR_CLASS (g_type_class_peek (VALA_TYPE_DESTRUCTOR));
	parent_class = G_OBJECT_CLASS (g_type_class_peek_parent (klass));
	parent_class->dispose (obj);
}


GType vala_destructor_get_type (void)
{
	static GType vala_destructor_type_id = 0;
	if (G_UNLIKELY (vala_destructor_type_id == 0)) {
		static const GTypeInfo g_define_type_info = { sizeof (ValaDestructorClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_destructor_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaDestructor), 0, (GInstanceInitFunc) vala_destructor_init };
		vala_destructor_type_id = g_type_register_static (VALA_TYPE_SYMBOL, "ValaDestructor", &g_define_type_info, 0);
	}
	return vala_destructor_type_id;
}
